summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lib/ssh/doc/src/SSH_app.xml2
-rw-r--r--lib/ssh/doc/src/configurations.xml2
-rw-r--r--lib/ssh/doc/src/configure_algos.xml16
-rw-r--r--lib/ssh/doc/src/hardening.xml4
-rw-r--r--lib/ssh/doc/src/notes.xml26
-rw-r--r--lib/ssh/doc/src/ssh.xml20
-rw-r--r--lib/ssh/doc/src/ssh_agent.xml2
-rw-r--r--lib/ssh/doc/src/ssh_client_key_api.xml12
-rw-r--r--lib/ssh/doc/src/ssh_connection.xml2
-rw-r--r--lib/ssh/doc/src/ssh_file.xml4
-rw-r--r--lib/ssh/doc/src/ssh_sftp.xml2
-rw-r--r--lib/ssh/doc/src/terminology.xml8
-rw-r--r--lib/ssh/doc/src/using_ssh.xml2
-rw-r--r--lib/ssh/src/ssh.erl2
-rw-r--r--lib/ssh/src/ssh_auth.hrl2
-rw-r--r--lib/ssh/src/ssh_client_key_api.erl2
-rw-r--r--lib/ssh/src/ssh_connection.erl4
-rw-r--r--lib/ssh/src/ssh_connection_handler.erl14
-rw-r--r--lib/ssh/src/ssh_daemon_channel.erl2
-rw-r--r--lib/ssh/src/ssh_dbg.erl8
-rw-r--r--lib/ssh/src/ssh_file.erl2
-rw-r--r--lib/ssh/src/ssh_fsm_userauth_client.erl6
-rw-r--r--lib/ssh/src/ssh_info.erl2
-rw-r--r--lib/ssh/src/ssh_message.erl4
-rw-r--r--lib/ssh/src/ssh_options.erl6
-rw-r--r--lib/ssh/src/ssh_server_channel.erl2
-rw-r--r--lib/ssh/src/ssh_server_key_api.erl2
-rw-r--r--lib/ssh/src/ssh_sftp.erl10
-rw-r--r--lib/ssh/src/ssh_sftpd.erl2
-rw-r--r--lib/ssh/src/ssh_shell.erl2
-rw-r--r--lib/ssh/src/ssh_system_sup.erl4
-rw-r--r--lib/ssh/src/ssh_transport.erl4
-rw-r--r--lib/ssh/src/ssh_transport.hrl2
-rw-r--r--lib/ssh/src/ssh_xfer.hrl2
-rw-r--r--lib/ssh/test/property_test/ssh_eqc_client_server.erl2
-rw-r--r--lib/ssh/test/property_test/ssh_eqc_encode_decode.erl2
-rw-r--r--lib/ssh/test/ssh_basic_SUITE.erl12
-rw-r--r--lib/ssh/test/ssh_chan_behaviours_SUITE.erl4
-rw-r--r--lib/ssh/test/ssh_compat_SUITE.erl10
-rw-r--r--lib/ssh/test/ssh_connection_SUITE.erl6
-rw-r--r--lib/ssh/test/ssh_options_SUITE.erl8
-rw-r--r--lib/ssh/test/ssh_protocol_SUITE.erl10
-rw-r--r--lib/ssh/test/ssh_pubkey_SUITE.erl4
-rw-r--r--lib/ssh/test/ssh_pubkey_SUITE_data/public_key/ssh_rsa_long_comment_pub2
-rw-r--r--lib/ssh/test/ssh_pubkey_SUITE_data/public_key/ssh_rsa_long_header_pub2
-rw-r--r--lib/ssh/test/ssh_relay.erl2
-rw-r--r--lib/ssh/test/ssh_sftpd_SUITE.erl6
-rw-r--r--lib/ssh/test/ssh_test_lib.erl6
-rw-r--r--lib/ssh/test/ssh_to_openssh_SUITE.erl2
-rw-r--r--lib/ssh/test/ssh_trpt_test_lib.erl14
-rw-r--r--lib/ssh/test/ssh_upgrade_SUITE.erl2
51 files changed, 140 insertions, 140 deletions
diff --git a/lib/ssh/doc/src/SSH_app.xml b/lib/ssh/doc/src/SSH_app.xml
index 8f3b5fc80b..4d12669c1e 100644
--- a/lib/ssh/doc/src/SSH_app.xml
+++ b/lib/ssh/doc/src/SSH_app.xml
@@ -282,7 +282,7 @@
</section>
<section>
<title>Unicode support</title>
- <p>Unicode filenames are supported if the emulator and the underlaying OS support it. See section DESCRIPTION in the
+ <p>Unicode filenames are supported if the emulator and the underlying OS support it. See section DESCRIPTION in the
<seeerl marker="kernel:file">file</seeerl> manual page in Kernel for information about this subject.
</p>
<p>The shell and the cli both support unicode.
diff --git a/lib/ssh/doc/src/configurations.xml b/lib/ssh/doc/src/configurations.xml
index cd55e87027..6123094673 100644
--- a/lib/ssh/doc/src/configurations.xml
+++ b/lib/ssh/doc/src/configurations.xml
@@ -250,7 +250,7 @@ ok
]).
{ok,&gt;0.118.0>}
</code>
- <p>We check which algoritms are negotiated by the client and the server, and note that
+ <p>We check which algorithms are negotiated by the client and the server, and note that
the (only) <c>kex</c> algorithm <c>'curve25519-sha256@libssh.org'</c> was selected:
</p>
<code>
diff --git a/lib/ssh/doc/src/configure_algos.xml b/lib/ssh/doc/src/configure_algos.xml
index acc6269da5..df4ed145a6 100644
--- a/lib/ssh/doc/src/configure_algos.xml
+++ b/lib/ssh/doc/src/configure_algos.xml
@@ -75,15 +75,15 @@
<tag><c>public_key</c></tag>
<item>
<p>Server host key</p>
- <p>The asymetric encryption algorithm used in the server's private-public host key pair.
+ <p>The asymmetric encryption algorithm used in the server's private-public host key pair.
Examples include the well-known RSA <c>'ssh-rsa'</c> and elliptic curve <c>'ecdsa-sha2-nistp521'</c>.
</p>
</item>
<tag><c>cipher</c></tag>
<item>
- <p>Symetric cipher algorithm used for the payload encryption. This algorithm will use the key calculated
- in the kex phase (together with other info) to genereate the actual key used. Examples are
+ <p>Symmetric cipher algorithm used for the payload encryption. This algorithm will use the key calculated
+ in the kex phase (together with other info) to generate the actual key used. Examples are
tripple-DES <c>'3des-cbc'</c> and one of many AES variants <c>'aes192-ctr'</c>.
</p>
<p>This list is actually two - one for each direction server-to-client and client-to-server. Therefore it
@@ -110,13 +110,13 @@
<section>
<title>The SSH app's mechanism</title>
- <p>The set of algorithms that the SSH app uses by default depends on the algoritms supported by the:</p>
+ <p>The set of algorithms that the SSH app uses by default depends on the algorithms supported by the:</p>
<list>
<item><p><seeerl marker="crypto:crypto">crypto</seeerl> app,</p>
</item>
- <item><p>The cryptolib OTP is linked with, usally the one the OS uses, probably OpenSSL,</p>
+ <item><p>The cryptolib OTP is linked with, usually the one the OS uses, probably OpenSSL,</p>
</item>
- <item><p>and finaly what the SSH app implements</p>
+ <item><p>and finally what the SSH app implements</p>
</item>
</list>
<p>Due to this, it impossible to list in documentation what algorithms that are available in a certain installation.</p>
@@ -170,7 +170,7 @@
<p>To forsee the effect of an option there is an experimental function <c>ssh:chk_algos_opts(Opts)</c>.
It mangles the options <c>preferred_algorithms</c>
- and <c>modify_algorithms</c> in the same way as <c>ssh:dameon</c>, <c>ssh:connect</c> and their friends does.</p>
+ and <c>modify_algorithms</c> in the same way as <c>ssh:daemon</c>, <c>ssh:connect</c> and their friends does.</p>
<section>
<title>Example 1</title>
@@ -322,7 +322,7 @@
<section>
<title>Example 5</title>
<p>As an example let's add the Diffie-Hellman Group1 first in the kex list. It is supported according to
- <seeapp marker="SSH_app#supported_algos">Supported algoritms</seeapp>.</p>
+ <seeapp marker="SSH_app#supported_algos">Supported algorithms</seeapp>.</p>
<code type="erl">
5> ssh:chk_algos_opts(
[{modify_algorithms,
diff --git a/lib/ssh/doc/src/hardening.xml b/lib/ssh/doc/src/hardening.xml
index c1d3f7669c..2aa8194b8f 100644
--- a/lib/ssh/doc/src/hardening.xml
+++ b/lib/ssh/doc/src/hardening.xml
@@ -64,7 +64,7 @@
<item>
If the client fails to send the first ssh message after a tcp connection setup
within this time (in milliseconds), the connection is closed.
- The default value is 30 seconds. This is actualy a generous time, so it can lowered
+ The default value is 30 seconds. This is actually a generous time, so it can lowered
to make the daemon less prone to DoS attacks.
</item>
<tag><seetype marker="ssh#negotiation_timeout_daemon_option">negotiation_timeout</seetype></tag>
@@ -251,7 +251,7 @@ end.
<code>
ssh:daemon(1234, [{id_string,"hi there"}, ... ]).
</code>
- <p>and the deamon will present itself as:</p>
+ <p>and the daemon will present itself as:</p>
<pre>SSH-2.0-hi there</pre>
<p>It is possible to replace the string with one randomly generated for each connection attempt.
See the reference manual for <seetype marker="ssh#id_string_common_option">id_string</seetype>.
diff --git a/lib/ssh/doc/src/notes.xml b/lib/ssh/doc/src/notes.xml
index 048ea11bf9..3c90a5015e 100644
--- a/lib/ssh/doc/src/notes.xml
+++ b/lib/ssh/doc/src/notes.xml
@@ -1031,7 +1031,7 @@
input/output, the I/O was erroneously handled by the
*server's* group leader, so the I/O turned up in the the
server's Erlang shell (if any). The user at the client
- side did therefor not see that I/O.</p>
+ side did therefore not see that I/O.</p>
<p>
This is corrected now, so the client - for example the
ssh OS shell command - handles the I/O. The user could
@@ -1576,7 +1576,7 @@
</item>
<item>
<p>
- The type specifications in SSH are completly reworked and
+ The type specifications in SSH are completely reworked and
the following types are renamed:</p>
<p>
<c>ssh:ssh_connection_ref()</c> is changed to
@@ -1841,7 +1841,7 @@
</item>
<item>
<p>
- Fix rare spurios shutdowns of ssh servers when receiveing
+ Fix rare spurious shutdowns of ssh servers when receiving
<c>{'EXIT',_,normal}</c> messages.</p>
<p>
Own Id: OTP-15018</p>
@@ -2292,7 +2292,7 @@
<list>
<item>
<p>
- Fix rare spurios shutdowns of ssh servers when receiveing
+ Fix rare spurious shutdowns of ssh servers when receiving
<c>{'EXIT',_,normal}</c> messages.</p>
<p>
Own Id: OTP-15018</p>
@@ -2524,7 +2524,7 @@
<item>
<p>
If a client illegaly sends an info-line and then
- immediatly closes the TCP-connection, a badmatch
+ immediately closes the TCP-connection, a badmatch
exception was raised.</p>
<p>
Own Id: OTP-13966</p>
@@ -2737,7 +2737,7 @@
<list>
<item>
<p>
- Fix rare spurios shutdowns of ssh servers when receiveing
+ Fix rare spurious shutdowns of ssh servers when receiving
<c>{'EXIT',_,normal}</c> messages.</p>
<p>
Own Id: OTP-15018</p>
@@ -3359,7 +3359,7 @@
<p>
The possible values are: <c>{id_string,string()}</c> and
<c>{id_string,random}</c>. The latter will make ssh
- generate a random nonsence id-string for each new
+ generate a random nonsense id-string for each new
connection.</p>
<p>
Own Id: OTP-12659</p>
@@ -3485,7 +3485,7 @@
<p>
The possible values are: <c>{id_string,string()}</c> and
<c>{id_string,random}</c>. The latter will make ssh
- generate a random nonsence id-string for each new
+ generate a random nonsense id-string for each new
connection.</p>
<p>
Own Id: OTP-12659</p>
@@ -4148,7 +4148,7 @@
<list>
<item>
<p>
- ssh:daemon will get feeded with an argument even if it is
+ ssh:daemon will get fed with an argument even if it is
not a valid expression.</p>
<p>
Own Id: OTP-10975</p>
@@ -4496,7 +4496,7 @@
<list>
<item>
<p>
- All keys in authorized_keys are considerd, wrongly only
+ All keys in authorized_keys are considered, wrongly only
the first one was before.</p>
<p>
Own Id: OTP-7235</p>
@@ -4870,7 +4870,7 @@
<list>
<item>
<p>
- Now clear all processes when a connnection is terminated.</p>
+ Now clear all processes when a connection is terminated.</p>
<p>
Own Id: OTP-8121 Aux Id:</p>
</item>
@@ -4968,13 +4968,13 @@
<list>
<item>
<p>
- ssh_sftp:start_channel/3 did not handle timout correctly.</p>
+ ssh_sftp:start_channel/3 did not handle timeout correctly.</p>
<p>
Own Id: OTP-8159 Aux Id: seq11386</p>
</item>
<item>
<p>
- If a progress message was not recieved after invoking ssh:connect/3
+ If a progress message was not received after invoking ssh:connect/3
the call could hang for ever. A timeout option has also been added.</p>
<p>
Own Id: OTP-8160 Aux Id: seq11386</p>
diff --git a/lib/ssh/doc/src/ssh.xml b/lib/ssh/doc/src/ssh.xml
index 44188ea34c..b6c84f40b4 100644
--- a/lib/ssh/doc/src/ssh.xml
+++ b/lib/ssh/doc/src/ssh.xml
@@ -64,7 +64,7 @@
<p>To just run a shell on a remote machine, there are functions that bundles the needed
three steps needed into one:
<seemfa marker="#shell/1">shell/1,2,3</seemfa>.
- Similarily, to just open an sftp (file transfer) connection to a remote machine, the simplest way is to use
+ Similarly, to just open an sftp (file transfer) connection to a remote machine, the simplest way is to use
<seemfa marker="ssh_sftp#start_channel/1">ssh_sftp:start_channel/1,2,3</seemfa>.
</p>
<p>To write your own client channel handler, use the behaviour
@@ -102,7 +102,7 @@
<seetype marker="ssh_file#user_dir_common_option"><c>user_dir</c></seetype> and
<seetype marker="ssh_file#system_dir_daemon_option"><c>system_dir</c></seetype>.
</p>
- <p>A completly different storage could be interfaced by writing call-back modules
+ <p>A completely different storage could be interfaced by writing call-back modules
using the behaviours
<seeerl marker="ssh_client_key_api">ssh_client_key_api</seeerl> and/or
<seeerl marker="ssh_server_key_api">ssh_server_key_api</seeerl>.
@@ -440,8 +440,8 @@
</p>
<p>In case of the <c>{direct, exec_fun()}</c> variant or no exec-option at all,
all reads from <c>standard_input</c> will be from the received data-events of type 0.
- Those are sent by the client. Similarily all writes to <c>standard_output</c>
- will be sent as data-events to the client. An OS shell client like the command 'ssh' will usally use
+ Those are sent by the client. Similarly all writes to <c>standard_output</c>
+ will be sent as data-events to the client. An OS shell client like the command 'ssh' will usually use
stdin and stdout for the user interface.
</p>
<p>The option cooperates with the daemon-option <seetype marker="#shell_daemon_option"><c>shell</c></seetype>
@@ -605,7 +605,7 @@
<seetype marker="#pwdfun_4"><c>pwdfun_4()</c></seetype>
</tag>
<item>
- <p>Provides a function for password validation. This could used for calling an external system or handeling
+ <p>Provides a function for password validation. This could used for calling an external system or handling
passwords stored as hash values.
</p>
<p>This fun can also be used to make delays in authentication tries for example by calling
@@ -1051,7 +1051,7 @@
<desc>
<p>Modifies the list of algorithms to use in the algorithm negotiation. The modifications are
applied after the option <c>preferred_algorithms</c> (if existing) is applied.</p>
- <p>The algoritm for modifications works like this:</p>
+ <p>The algorithm for modifications works like this:</p>
<list>
<item>
<p>Input is the <c>modify_algs_list()</c> and a set of algorithms <c>A</c>
@@ -1318,7 +1318,7 @@
<p>are allowed. The excluded options are reserved by the SSH application.
</p>
<warning>
- <p>This is an extremly dangerous function. You use it on your own risk.</p>
+ <p>This is an extremely dangerous function. You use it on your own risk.</p>
<p>Some options are OS and OS version dependent.
Do not use it unless you know what effect your option values will have
on an TCP stream.</p>
@@ -1340,7 +1340,7 @@
</desc>
</func>
-<!-- DEAMON/1,2,3 -->
+<!-- DAEMON/1,2,3 -->
<func>
<name since="">daemon(Port | TcpSocket) -> Result</name>
<name since="">daemon(Port | TcpSocket, Options) -> Result</name>
@@ -1374,7 +1374,7 @@
An 'ip'-option will be discarded if present.</item>
<item>if <c>HostAddress</c> is the atom <c>loopback</c>, the listening address
- is <c>loopback</c> and an loopback address will be choosen by the underlying layers.
+ is <c>loopback</c> and an loopback address will be chosen by the underlying layers.
An 'ip'-option will be discarded if present.</item>
<item>if <c>HostAddress</c> is the atom <c>any</c> and no 'ip'-option is present, the listening address is
@@ -1433,7 +1433,7 @@
interactive shell on that remote host.
</p>
<p>As an alternative, an already open TCP socket could be passed to the function in <c>TcpSocket</c>.
- The SSH initiation and negotiation will be initiated on that one and finaly a shell will be started
+ The SSH initiation and negotiation will be initiated on that one and finally a shell will be started
on the host at the other end of the TCP socket.
</p>
<p>For a description of the options, see <seetype marker="#client_options">Client Options</seetype>.</p>
diff --git a/lib/ssh/doc/src/ssh_agent.xml b/lib/ssh/doc/src/ssh_agent.xml
index a6ff511f2f..ceada72371 100644
--- a/lib/ssh/doc/src/ssh_agent.xml
+++ b/lib/ssh/doc/src/ssh_agent.xml
@@ -52,7 +52,7 @@
</code>
<p>
The agent communication is established through a UNIX domain socket. By default, the socket path
- will be fetched from the <c>SSH_AUTH_SOCK</c> enviroment variable, which is the default socket path in the agent
+ will be fetched from the <c>SSH_AUTH_SOCK</c> environment variable, which is the default socket path in the agent
implementation of
<url href="http://www.openssh.com">OpenSSH</url>.
</p>
diff --git a/lib/ssh/doc/src/ssh_client_key_api.xml b/lib/ssh/doc/src/ssh_client_key_api.xml
index a81d0d3274..cb20724496 100644
--- a/lib/ssh/doc/src/ssh_client_key_api.xml
+++ b/lib/ssh/doc/src/ssh_client_key_api.xml
@@ -69,7 +69,7 @@
<v>ConnectOptions = <seetype marker="#client_key_cb_options">client_key_cb_options()</seetype></v>
</type>
<desc>
- <p>This function is retired in favour for <c>Module:add_host_key/4</c> which is the prefered API function.
+ <p>This function is retired in favour for <c>Module:add_host_key/4</c> which is the preferred API function.
The calling SSH application will still try the <c>add_host_key/3</c> if the call to <c>add_host_key/4</c> failed.
</p>
<p>Adds a host key to the set of trusted host keys.</p>
@@ -96,10 +96,10 @@
</type>
<desc>
<p>Adds a host key to the set of trusted host keys.</p>
- <p>This function is prefered to the old <c>Module:add_host_key/3</c> since it also uses
+ <p>This function is preferred to the old <c>Module:add_host_key/3</c> since it also uses
the peer host port number and may return an error message.</p>
<p>The OTP/SSH application first calls this function in the callback module, and then
- the old <c>Module:add_host_key/3</c> for compatibilty.</p>
+ the old <c>Module:add_host_key/3</c> for compatibility.</p>
</desc>
</func>
@@ -121,7 +121,7 @@
<v>Result = boolean()</v>
</type>
<desc>
- <p>This function is retired in favour for <c>Module:is_host_key/5</c> which is the prefered API function.
+ <p>This function is retired in favour for <c>Module:is_host_key/5</c> which is the preferred API function.
The calling SSH application will still try the <c>is_host_key/4</c> if the call to <c>is_host_key/5</c> failed.
</p>
<p>Checks if a host key is trusted.</p>
@@ -155,10 +155,10 @@
</type>
<desc>
<p>Checks if a host key is trusted.</p>
- <p>This function is prefered to the old <c>Module:is_host_key/4</c> since it also uses
+ <p>This function is preferred to the old <c>Module:is_host_key/4</c> since it also uses
the peer host port number and may return an error message.</p>
<p>The OTP/SSH application first calls this function in the callback module, and then
- the old <c>Module:is_host_key/4</c> for compatibilty.</p>
+ the old <c>Module:is_host_key/4</c> for compatibility.</p>
</desc>
</func>
diff --git a/lib/ssh/doc/src/ssh_connection.xml b/lib/ssh/doc/src/ssh_connection.xml
index cd4b9c0f85..6aac917ed3 100644
--- a/lib/ssh/doc/src/ssh_connection.xml
+++ b/lib/ssh/doc/src/ssh_connection.xml
@@ -85,7 +85,7 @@
<name name="req_status"/>
<desc>
<p>The status of a request.
- Coresponds to the <c>SSH_MSG_CHANNEL_SUCCESS</c> and <c>SSH_MSG_CHANNEL_FAILURE</c> values in
+ Corresponds to the <c>SSH_MSG_CHANNEL_SUCCESS</c> and <c>SSH_MSG_CHANNEL_FAILURE</c> values in
<url href="https://tools.ietf.org/html/rfc4254#section-5.4">RFC 4254, Section 5.4</url>.
</p>
</desc>
diff --git a/lib/ssh/doc/src/ssh_file.xml b/lib/ssh/doc/src/ssh_file.xml
index 941d68d297..3af6a0777c 100644
--- a/lib/ssh/doc/src/ssh_file.xml
+++ b/lib/ssh/doc/src/ssh_file.xml
@@ -66,7 +66,7 @@
<title>Daemons</title>
<p>Daemons uses all files stored in the <seeerl marker="#SYSDIR">SYSDIR</seeerl> directory.
</p>
- <p>Optionaly, in case of <c>publickey</c> authorization, one or more of the remote user's public keys
+ <p>Optionally, in case of <c>publickey</c> authorization, one or more of the remote user's public keys
in the <seeerl marker="#USERDIR">USERDIR</seeerl> directory are used.
See the files
<seeerl marker="#FILE-authorized_keys"><c>USERDIR/authorized_keys</c></seeerl> and
@@ -267,7 +267,7 @@ key :: % encoded key from eg ssh_host_*.pub
<item><seeerl marker="#FILE-authorized_keys"><c>USERDIR/authorized_keys</c></seeerl></item>
<item><seeerl marker="#FILE-authorized_keys2"><c>USERDIR/authorized_keys2</c></seeerl></item>
</list>
- <p>This functions discards all options in the begining of the lines of thoose files when reading them.
+ <p>This functions discards all options in the beginning of the lines of thoose files when reading them.
</p>
</desc>
</func>
diff --git a/lib/ssh/doc/src/ssh_sftp.xml b/lib/ssh/doc/src/ssh_sftp.xml
index 6e30c1e20d..2c8f785e11 100644
--- a/lib/ssh/doc/src/ssh_sftp.xml
+++ b/lib/ssh/doc/src/ssh_sftp.xml
@@ -96,7 +96,7 @@
<seemfa marker="crypto:crypto#crypto_init/4">crypto:crypto_init/4</seemfa>
or similar. The <c>crypto_state()</c> is the state such a function may return.
</p>
- <p>If the selected cipher needs to have the input data partioned into
+ <p>If the selected cipher needs to have the input data partitioned into
blocks of a certain size, the <c>init_fun()</c> should return the second
form of return value with the <c>chunk_size()</c> set to the block size.
If the <c>chunk_size()</c> is <c>undefined</c>, the size of the <c>PlainBin</c>s varies,
diff --git a/lib/ssh/doc/src/terminology.xml b/lib/ssh/doc/src/terminology.xml
index 9766276192..78a24f1618 100644
--- a/lib/ssh/doc/src/terminology.xml
+++ b/lib/ssh/doc/src/terminology.xml
@@ -44,7 +44,7 @@
cause confusion.
</p>
<p>The term is used differently in <url href="http://www.openssh.com">OpenSSH</url> and SSH in Erlang/OTP.
- The reason is the different environments and use cases that are not immediatly obvious.
+ The reason is the different environments and use cases that are not immediately obvious.
</p>
<p>This chapter aims at explaining the differences and giving a rationale for why Erlang/OTP handles "user" as
it does.
@@ -95,8 +95,8 @@
</p>
</section>
<section>
- <title>The SSH server on UNIX/Linux/etc after a succesful authentication</title>
- <p>After a succesful incoming authentication, a new process runs as the just authenticated user.</p>
+ <title>The SSH server on UNIX/Linux/etc after a successful authentication</title>
+ <p>After a successful incoming authentication, a new process runs as the just authenticated user.</p>
<p>Next step is to start a service according to the ssh request. In case of a request of a shell,
a new one is started which handles the OS-commands that arrives from the client (that's "you").
</p>
@@ -166,7 +166,7 @@
</list>
</section>
<section>
- <title>The Erlang/OTP SSH server after a succesful authentication</title>
+ <title>The Erlang/OTP SSH server after a successful authentication</title>
<p>After a successful authentication an <i>Erlang process</i> is handling the service request from the remote
ssh client. The rights of that process are those of the user of the OS process running the Erlang emulator.
</p>
diff --git a/lib/ssh/doc/src/using_ssh.xml b/lib/ssh/doc/src/using_ssh.xml
index a127b66607..81d19a70be 100644
--- a/lib/ssh/doc/src/using_ssh.xml
+++ b/lib/ssh/doc/src/using_ssh.xml
@@ -201,7 +201,7 @@ ok
<p>To close the connection, call the function <seemfa marker="ssh#close/1"><c>ssh:close(ConnectionRef)</c></seemfa>.
As an alternative, set the option
<seetype marker="ssh#max_idle_time_common_option"><c>{idle_time, 1}</c></seetype>
- when opening the connection. This will cause the connection to be closed automaticaly when there are
+ when opening the connection. This will cause the connection to be closed automatically when there are
no channels open for the specified time period, in this case 1 ms.
</p>
</section>
diff --git a/lib/ssh/src/ssh.erl b/lib/ssh/src/ssh.erl
index f655f0db45..320a1992bc 100644
--- a/lib/ssh/src/ssh.erl
+++ b/lib/ssh/src/ssh.erl
@@ -108,7 +108,7 @@ start(Type) ->
{ok, _} ->
%% Clear cached default_algorithms (if exists) ...
ssh_transport:clear_default_algorithms_env(),
- %% ... and rebuld them taking configure options in account
+ %% ... and rebuild them taking configure options in account
ssh_transport:default_algorithms(),
ok;
Other ->
diff --git a/lib/ssh/src/ssh_auth.hrl b/lib/ssh/src/ssh_auth.hrl
index 56314ca6d9..71d0c394cb 100644
--- a/lib/ssh/src/ssh_auth.hrl
+++ b/lib/ssh/src/ssh_auth.hrl
@@ -59,7 +59,7 @@
-record(ssh_msg_userauth_passwd_changereq,
{
prompt, %% string
- languge %% string
+ language %% string
}).
-record(ssh_msg_userauth_pk_ok,
diff --git a/lib/ssh/src/ssh_client_key_api.erl b/lib/ssh/src/ssh_client_key_api.erl
index 367d78bf22..1cc153904f 100644
--- a/lib/ssh/src/ssh_client_key_api.erl
+++ b/lib/ssh/src/ssh_client_key_api.erl
@@ -82,7 +82,7 @@
%%% in the argument Host with the port Port.
%%%
%%% Due to compatibility reasons, the OTP/SSH application first
-%%% trys add_host_key/4 and then the old add_host_key/3
+%%% tries add_host_key/4 and then the old add_host_key/3
-callback add_host_key(Host :: inet:ip_address() | inet:hostname()
| [inet:ip_address() | inet:hostname()],
diff --git a/lib/ssh/src/ssh_connection.erl b/lib/ssh/src/ssh_connection.erl
index a67f511e1a..733283143b 100644
--- a/lib/ssh/src/ssh_connection.erl
+++ b/lib/ssh/src/ssh_connection.erl
@@ -177,7 +177,7 @@
Command :: string()
} .
-%%% This function is soley to convince all
+%%% This function is solely to convince all
%%% checks that the type event() exists...
-export([dummy/1]).
-spec dummy(event()) -> false.
@@ -404,7 +404,7 @@ ptty_alloc(ConnectionHandler, Channel, Options0, TimeOut) ->
).
%%--------------------------------------------------------------------
-%% Not yet officialy supported! The following functions are part of the
+%% Not yet officially supported! The following functions are part of the
%% initial contributed ssh application. They are untested. Do we want them?
%% Should they be documented and tested?
%%--------------------------------------------------------------------
diff --git a/lib/ssh/src/ssh_daemon_channel.erl b/lib/ssh/src/ssh_daemon_channel.erl
index 30c4773a7a..9673ad0797 100644
--- a/lib/ssh/src/ssh_daemon_channel.erl
+++ b/lib/ssh/src/ssh_daemon_channel.erl
@@ -25,7 +25,7 @@
-module(ssh_daemon_channel).
-%% API to server side channel that can be pluged into the erlang ssh daemeon
+%% API to server side channel that can be plugged into the erlang ssh daemeon
-callback init(Args :: term()) ->
{ok, State :: term()} | {ok, State :: term(), timeout() | hibernate} |
{stop, Reason :: term()} | ignore.
diff --git a/lib/ssh/src/ssh_dbg.erl b/lib/ssh/src/ssh_dbg.erl
index 54a88a479f..6a21b876da 100644
--- a/lib/ssh/src/ssh_dbg.erl
+++ b/lib/ssh/src/ssh_dbg.erl
@@ -156,7 +156,7 @@ go_on() ->
on(IsOn).
%%%----------------------------------------------------------------
-shrink_bin(B) when is_binary(B), size(B)>256 -> {'*** SHRINKED BIN',
+shrink_bin(B) when is_binary(B), size(B)>256 -> {'*** SHRUNK BIN',
size(B),
element(1,split_binary(B,64)),
'...',
@@ -167,13 +167,13 @@ shrink_bin(T) when is_tuple(T) -> list_to_tuple(shrink_bin(tuple_to_list(T)));
shrink_bin(X) -> X.
%%%----------------------------------------------------------------
-%% Replace any occurence of {Name,...}, with "#Name{}"
+%% Replace any occurrence of {Name,...}, with "#Name{}"
reduce_state(T, RecordExample) ->
Name = element(1, RecordExample),
Arity = size(RecordExample),
reduce_state(T, Name, Arity).
-%% Replace any occurence of {Name,...}, with "#Name{}"
+%% Replace any occurrence of {Name,...}, with "#Name{}"
reduce_state(T, Name, Arity) when element(1,T) == Name,
size(T) == Arity ->
lists:concat(['#',Name,'{}']);
@@ -400,7 +400,7 @@ try_all_types_in_all_modules(TypesOn, Arg, WriteFun, Acc0) ->
catch
_:_ ->
%% and finally, signal for special formatting
- %% if noone else formats it
+ %% if no one else formats it
Acc
end
end
diff --git a/lib/ssh/src/ssh_file.erl b/lib/ssh/src/ssh_file.erl
index 3e3a2a770f..c87106579e 100644
--- a/lib/ssh/src/ssh_file.erl
+++ b/lib/ssh/src/ssh_file.erl
@@ -571,7 +571,7 @@ find_host_key(_, _, _, []) ->
revoked_key(Hosts, KeyType, EncKey, [<<"@revoked ",RestLine/binary>> | Lines]) ->
case binary:split(RestLine, <<" ">>, [global,trim_all]) of
[Patterns, KeyType, EncKey|_Comment] ->
- %% Very likeley to be a revoked key,
+ %% Very likely to be a revoked key,
%% but does any of the hosts match the pattern?
case host_match(Hosts, Patterns) of
true ->
diff --git a/lib/ssh/src/ssh_fsm_userauth_client.erl b/lib/ssh/src/ssh_fsm_userauth_client.erl
index e24e0e2f9a..73c8446639 100644
--- a/lib/ssh/src/ssh_fsm_userauth_client.erl
+++ b/lib/ssh/src/ssh_fsm_userauth_client.erl
@@ -55,13 +55,13 @@ callback_mode() ->
%%% ######## {userauth, client} ####
-%%---- #ssh_msg_ext_info could follow after the key exchange, both the intial and the re-negotiation
+%%---- #ssh_msg_ext_info could follow after the key exchange, both the initial and the re-negotiation
handle_event(internal, #ssh_msg_ext_info{}=Msg, {userauth,client}, D0) ->
%% FIXME: need new state to receive this msg!
D = ssh_connection_handler:handle_ssh_msg_ext_info(Msg, D0),
{keep_state, D};
-%%---- recevied userauth success from the server
+%%---- received userauth success from the server
handle_event(internal, #ssh_msg_userauth_success{}, {userauth,client}, D0=#data{ssh_params = Ssh}) ->
ssh_auth:ssh_msg_userauth_result(success),
ssh_connection_handler:handshake(ssh_connected, D0),
@@ -80,7 +80,7 @@ handle_event(internal, #ssh_msg_userauth_failure{}, {userauth,client}=StateName,
handle_event(internal, #ssh_msg_userauth_failure{authentications = Methods}, StateName={userauth,client},
D0 = #data{ssh_params = Ssh0}) ->
- %% The prefered authentication method failed, try next method
+ %% The preferred authentication method failed, try next method
Ssh1 = case Ssh0#ssh.userauth_methods of
none ->
%% Server tells us which authentication methods that are allowed
diff --git a/lib/ssh/src/ssh_info.erl b/lib/ssh/src/ssh_info.erl
index b1b4d0ea56..aa7324b588 100644
--- a/lib/ssh/src/ssh_info.erl
+++ b/lib/ssh/src/ssh_info.erl
@@ -20,7 +20,7 @@
%%
%%----------------------------------------------------------------------
-%% Purpose: Print some info of a running ssh aplication.
+%% Purpose: Print some info of a running ssh application.
%%----------------------------------------------------------------------
-module(ssh_info).
diff --git a/lib/ssh/src/ssh_message.erl b/lib/ssh/src/ssh_message.erl
index 0f30ab2cf5..60fd6f93c3 100644
--- a/lib/ssh/src/ssh_message.erl
+++ b/lib/ssh/src/ssh_message.erl
@@ -172,7 +172,7 @@ encode(#ssh_msg_userauth_pk_ok{
<<?Ebyte(?SSH_MSG_USERAUTH_PK_OK), ?Estring(Alg), ?Ebinary(KeyBlob)>>;
encode(#ssh_msg_userauth_passwd_changereq{prompt = Prompt,
- languge = Lang
+ language = Lang
})->
<<?Ebyte(?SSH_MSG_USERAUTH_PASSWD_CHANGEREQ), ?Estring_utf8(Prompt), ?Estring(Lang)>>;
@@ -438,7 +438,7 @@ decode(<<?BYTE(?SSH_MSG_USERAUTH_INFO_REQUEST),
decode(<<?BYTE(?SSH_MSG_USERAUTH_PASSWD_CHANGEREQ), ?DEC_BIN(Prompt,__0), ?DEC_BIN(Lang,__1) >>) ->
#ssh_msg_userauth_passwd_changereq{
prompt = Prompt,
- languge = Lang
+ language = Lang
};
%%% Unhandled message, also masked by same 1:st byte value as ?SSH_MSG_USERAUTH_INFO_REQUEST:
diff --git a/lib/ssh/src/ssh_options.erl b/lib/ssh/src/ssh_options.erl
index e06c2ed27c..686fa27b58 100644
--- a/lib/ssh/src/ssh_options.erl
+++ b/lib/ssh/src/ssh_options.erl
@@ -295,7 +295,7 @@ save({Inet,false}, _Defs, OptMap) when Inet==inet ; Inet==inet6 -> OptMap;
save({special_trpt_args,T}, _Defs, OptMap) when is_map(OptMap) ->
OptMap#{socket_options := [T | maps:get(socket_options,OptMap)]};
-%% and finaly the 'real stuff':
+%% and finally the 'real stuff':
save({Key,Value}, Defs, OptMap) when is_map(OptMap) ->
try (check_fun(Key,Defs))(Value)
of
@@ -1070,11 +1070,11 @@ normalize_mod_algs([K|Ks], KVs0, Acc, UseDefaultAlgs) ->
normalize_mod_algs(Ks, KVs, [{K,Vs} | Acc], UseDefaultAlgs);
normalize_mod_algs([], [], Acc, _) ->
%% No values left in the key-value list after removing the expected entries
- %% (thats good)
+ %% (that's good)
lists:reverse(Acc);
normalize_mod_algs([], [{K,_}|_], _, _) ->
%% Some values left in the key-value list after removing the expected entries
- %% (thats bad)
+ %% (that's bad)
case ssh_transport:algo_class(K) of
true -> error_in_check(K, "Duplicate key");
false -> error_in_check(K, "Unknown key")
diff --git a/lib/ssh/src/ssh_server_channel.erl b/lib/ssh/src/ssh_server_channel.erl
index 6339f13cad..87d32ccfb0 100644
--- a/lib/ssh/src/ssh_server_channel.erl
+++ b/lib/ssh/src/ssh_server_channel.erl
@@ -25,7 +25,7 @@
-module(ssh_server_channel).
-%% API to server side channel that can be pluged into the erlang ssh daemeon
+%% API to server side channel that can be plugged into the erlang ssh daemeon
-callback init(Args :: term()) ->
{ok, State :: term()} | {ok, State :: term(), timeout() | hibernate} |
{stop, Reason :: term()} | ignore.
diff --git a/lib/ssh/src/ssh_server_key_api.erl b/lib/ssh/src/ssh_server_key_api.erl
index addf46ef78..d668c8f61b 100644
--- a/lib/ssh/src/ssh_server_key_api.erl
+++ b/lib/ssh/src/ssh_server_key_api.erl
@@ -29,7 +29,7 @@
%%% The option key_cb_private is to pass options needed by other
%%% callback modules than the default ssh_file.erl
%%%
-%%% If ssh:deamon(n, [ {key_cb_private, {hi,{there}}} ]
+%%% If ssh:daemon(n, [ {key_cb_private, {hi,{there}}} ]
%%% is called, the term() will be {hi,{there}}
-type daemon_key_cb_options(T) :: [{key_cb_private,[T]} | ssh:daemon_option()].
diff --git a/lib/ssh/src/ssh_sftp.erl b/lib/ssh/src/ssh_sftp.erl
index c91f9d67ee..1558904928 100644
--- a/lib/ssh/src/ssh_sftp.erl
+++ b/lib/ssh/src/ssh_sftp.erl
@@ -78,7 +78,7 @@
mode, % read | write (=from or to buffer by user)
crypto_state,
crypto_fun, % For encode or decode depending on the mode field
- size = 0, % # bytes "before" the current buffer for the postion call
+ size = 0, % # bytes "before" the current buffer for the position call
chunksize, % The size of the chunks to be sent or received
enc_text_buf = <<>>, % Encrypted text
@@ -1224,7 +1224,7 @@ terminate(_Reason, State) ->
%% Internal functions
%%====================================================================
legacy_timeout(UserOptions) ->
- %% Make both connect_timeout and timeout defined if exaclty one of them is defined:
+ %% Make both connect_timeout and timeout defined if exactly one of them is defined:
case {proplists:get_value(connect_timeout, UserOptions),
proplists:get_value(timeout, UserOptions)} of
{undefined, undefined} ->
@@ -1582,7 +1582,7 @@ erase_handle(Handle, State) ->
State#state{inf = FI}.
%%
-%% Caluclate a integer offset
+%% Calculate a integer offset
%%
lseek_position(Handle, Pos, State) ->
case maps:find(Handle, State#state.inf) of
@@ -1719,7 +1719,7 @@ do_the_read_buf(Pid, SftpHandle, WantedLen, Packet, FileOpTimeout,
chunksize = undefined
})
when size(EncBuf0) > 0 ->
- %% We have (at least) one decodable byte waiting for decodeing.
+ %% We have (at least) one decodable byte waiting for decoding.
{ok,DecodedBin,B} = apply_crypto(EncBuf0, B0),
do_the_read_buf(Pid, SftpHandle, WantedLen, Packet, FileOpTimeout,
B#bufinf{plain_text_buf = <<PlainBuf0/binary, DecodedBin/binary>>,
@@ -1732,7 +1732,7 @@ do_the_read_buf(Pid, SftpHandle, WantedLen, Packet, FileOpTimeout,
chunksize = ChunkSize0
})
when size(EncBuf0) >= ChunkSize0 ->
- %% We have (at least) one chunk of decodable bytes waiting for decodeing.
+ %% We have (at least) one chunk of decodable bytes waiting for decoding.
<<ToDecode:ChunkSize0/binary, EncBuf/binary>> = EncBuf0,
{ok,DecodedBin,B} = apply_crypto(ToDecode, B0),
do_the_read_buf(Pid, SftpHandle, WantedLen, Packet, FileOpTimeout,
diff --git a/lib/ssh/src/ssh_sftpd.erl b/lib/ssh/src/ssh_sftpd.erl
index 27b97716eb..c86ed2cb81 100644
--- a/lib/ssh/src/ssh_sftpd.erl
+++ b/lib/ssh/src/ssh_sftpd.erl
@@ -102,7 +102,7 @@ init(Options) ->
%% Get the root of the file system (symlinks must be followed,
%% otherwise the realpath call won't work). But since symbolic links
- %% isn't supported on all plattforms we have to use the root property
+ %% isn't supported on all platforms we have to use the root property
%% supplied by the user.
{Root, State} =
case resolve_symlinks(Root0,
diff --git a/lib/ssh/src/ssh_shell.erl b/lib/ssh/src/ssh_shell.erl
index bd11afa080..bc7bd73a12 100644
--- a/lib/ssh/src/ssh_shell.erl
+++ b/lib/ssh/src/ssh_shell.erl
@@ -26,7 +26,7 @@
-include("ssh_connect.hrl").
%%% As this is an user interactive client it behaves like a daemon
-%%% channel inspite of it being a client.
+%%% channel in spite of it being a client.
-behaviour(ssh_server_channel).
%% ssh_server_channel callbacks
diff --git a/lib/ssh/src/ssh_system_sup.erl b/lib/ssh/src/ssh_system_sup.erl
index 728a10974c..712ca9a7fc 100644
--- a/lib/ssh/src/ssh_system_sup.erl
+++ b/lib/ssh/src/ssh_system_sup.erl
@@ -122,7 +122,7 @@ start_subsystem(Role, Address=#address{}, Socket, Options0) ->
{error,Error};
error:timeout ->
%% The connection was started, but the takover procedure timed out,
- %% therefor it exists a subtree, but it is not quite ready and
+ %% therefore it exists a subtree, but it is not quite ready and
%% must be removed (by the supervisor above):
supervisor:terminate_child(SysPid, Id),
{error, connection_start_timeout}
@@ -219,7 +219,7 @@ find_system_sup(Role, Address0) ->
case addresses(Role, Address0) of
[{SysSupPid,Address}] -> {ok,{SysSupPid,Address}};
[] -> {error,not_found};
- [_,_|_] -> {error,ambigous}
+ [_,_|_] -> {error,ambiguous}
end.
sup(client) -> sshc_sup;
diff --git a/lib/ssh/src/ssh_transport.erl b/lib/ssh/src/ssh_transport.erl
index e43c345130..3f14fad3e9 100644
--- a/lib/ssh/src/ssh_transport.erl
+++ b/lib/ssh/src/ssh_transport.erl
@@ -1274,8 +1274,8 @@ alg_final(rcv, SSH0) ->
select_all(CL, SL) when length(CL) + length(SL) < ?MAX_NUM_ALGORITHMS ->
- %% algortihms only used by client
- %% NOTE: an algorithm occuring more than once in CL will still be present
+ %% algorithms only used by client
+ %% NOTE: an algorithm occurring more than once in CL will still be present
%% in CLonly. This is not a problem for nice clients.
CLonly = CL -- SL,
diff --git a/lib/ssh/src/ssh_transport.hrl b/lib/ssh/src/ssh_transport.hrl
index f424a4ff63..c5424952c6 100644
--- a/lib/ssh/src/ssh_transport.hrl
+++ b/lib/ssh/src/ssh_transport.hrl
@@ -20,7 +20,7 @@
%%
%%----------------------------------------------------------------------
-%% Purpose: Record and constant defenitions for the SSH-tansport layer
+%% Purpose: Record and constant definitions for the SSH-tansport layer
%% protocol see RFC 4253
%%----------------------------------------------------------------------
diff --git a/lib/ssh/src/ssh_xfer.hrl b/lib/ssh/src/ssh_xfer.hrl
index 07467c474b..f5bca16116 100644
--- a/lib/ssh/src/ssh_xfer.hrl
+++ b/lib/ssh/src/ssh_xfer.hrl
@@ -226,7 +226,7 @@
-record(ssh_xfer_attr,
{
- type, %% regular, dirctory, symlink, ...
+ type, %% regular, directory, symlink, ...
size,
owner,
group,
diff --git a/lib/ssh/test/property_test/ssh_eqc_client_server.erl b/lib/ssh/test/property_test/ssh_eqc_client_server.erl
index 4bfc23d5ff..bb860a0d07 100644
--- a/lib/ssh/test/property_test/ssh_eqc_client_server.erl
+++ b/lib/ssh/test/property_test/ssh_eqc_client_server.erl
@@ -299,7 +299,7 @@ do(Pid, Fun, Timeout) when is_function(Fun,0) ->
%%%----------------
%%% Start a new connection
-%%% Precondition: deamon exists
+%%% Precondition: daemon exists
ssh_open_connection_pre(S) -> S#state.servers /= [].
diff --git a/lib/ssh/test/property_test/ssh_eqc_encode_decode.erl b/lib/ssh/test/property_test/ssh_eqc_encode_decode.erl
index 843a2b5a3c..51b0e8face 100644
--- a/lib/ssh/test/property_test/ssh_eqc_encode_decode.erl
+++ b/lib/ssh/test/property_test/ssh_eqc_encode_decode.erl
@@ -250,7 +250,7 @@ msg_code(Num) -> Name
-include_lib("ssh/src/ssh_connect.hrl").
-include_lib("ssh/src/ssh_transport.hrl").
-%%% Encoding and decodeing is asymetric so out=binary in=string. Sometimes. :(
+%%% Encoding and decoding is asymmetric so out=binary in=string. Sometimes. :(
-define(fix_asym_Xdh_reply(S),
fix_asym(#S{public_host_key = Key, h_sig = {Alg,Sig}} = M) ->
M#S{public_host_key = {Key, list_to_atom(Alg)}, h_sig = Sig}
diff --git a/lib/ssh/test/ssh_basic_SUITE.erl b/lib/ssh/test/ssh_basic_SUITE.erl
index 0c6bb4365f..f79b58e209 100644
--- a/lib/ssh/test/ssh_basic_SUITE.erl
+++ b/lib/ssh/test/ssh_basic_SUITE.erl
@@ -251,7 +251,7 @@ appup_test(Config) when is_list(Config) ->
%%--------------------------------------------------------------------
%%% Test that we can set some misc options not tested elsewhere
%%% some options not yet present are not decided if we should support or
-%%% if they need thier own test case.
+%%% if they need their own test case.
misc_ssh_options(Config) when is_list(Config) ->
SystemDir = filename:join(proplists:get_value(priv_dir, Config), system),
UserDir = proplists:get_value(priv_dir, Config),
@@ -520,7 +520,7 @@ shell_socket(Config) when is_list(Config) ->
ct:log("~p:~p udp socket failed ok", [?MODULE,?LINE]),
gen_udp:close(BadSock),
- %% And finaly test with passive mode (which should work):
+ %% And finally test with passive mode (which should work):
IO = ssh_test_lib:start_io_server(),
{ok,Sock} = gen_tcp:connect(Host, Port, [{active,false}]),
Shell = ssh_test_lib:start_shell(Sock, IO, [{user_dir,UserDir}]),
@@ -659,7 +659,7 @@ cli_exit_status(Config) when is_list(Config) ->
%%--------------------------------------------------------------------
%%% Test that get correct error message if you try to start a daemon
-%%% on an adress that already runs a daemon see also seq10667
+%%% on an address that already runs a daemon see also seq10667
daemon_already_started(Config) when is_list(Config) ->
SystemDir = proplists:get_value(data_dir, Config),
UserDir = proplists:get_value(priv_dir, Config),
@@ -1393,7 +1393,7 @@ login_bad_pwd_no_retry(Config, AuthMethods) ->
{ok,Conn} ->
ssh:close(Conn),
ssh:stop_daemon(DaemonRef),
- {fail, "Connect erroneosly succeded"}
+ {fail, "Connect erroneosly succeeded"}
end
end.
@@ -1465,7 +1465,7 @@ setopts_getopts(Config) ->
%% Internal functions ------------------------------------------------
%%--------------------------------------------------------------------
%% Due to timing the error message may or may not be delivered to
-%% the "tcp-application" before the socket closed message is recived
+%% the "tcp-application" before the socket closed message is received
check_error("Invalid state") -> ok;
check_error("Connection closed") -> ok;
check_error("Selection of key exchange algorithm failed"++_) -> ok;
@@ -1582,7 +1582,7 @@ prompt_prefix() ->
new_do_shell_prompt(IO, N, type, Str, More) ->
ct:log("Matched prompt ~p to trigger sending of next line to server",[N]),
IO ! {input, self(), Str++"\r\n"},
- ct:log("Promt '~p> ', Sent ~ts",[N,Str++"\r\n"]),
+ ct:log("Prompt '~p> ', Sent ~ts",[N,Str++"\r\n"]),
new_do_shell(IO, N, More);
new_do_shell_prompt(IO, N, Op, Str, More) ->
ct:log("Matched prompt ~p",[N]),
diff --git a/lib/ssh/test/ssh_chan_behaviours_SUITE.erl b/lib/ssh/test/ssh_chan_behaviours_SUITE.erl
index df37918228..c0ab325126 100644
--- a/lib/ssh/test/ssh_chan_behaviours_SUITE.erl
+++ b/lib/ssh/test/ssh_chan_behaviours_SUITE.erl
@@ -104,7 +104,7 @@ end_per_testcase(_TC, Config) ->
%%--------------------------------------------------------------------
%% Test Cases --------------------------------------------------------
%%--------------------------------------------------------------------
-%% Try start a subsystem whos name is not known by the server
+%% Try start a subsystem whose name is not known by the server
noexist_subsystem(Config) ->
C = proplists:get_value(connref, Config),
{ok, Ch} = ssh_connection:session_channel(C, infinity),
@@ -135,7 +135,7 @@ defined_subsystem(Config) ->
?EXPECT({ssh_cm, C, {closed,Ch1}}, []), % self() is instead of a proper channel handler
ok.
-%% Try to start and stop a subsystem from a ssh_client_channel behviour
+%% Try to start and stop a subsystem from a ssh_client_channel behaviour
subsystem_client(Config) ->
C = proplists:get_value(connref, Config),
diff --git a/lib/ssh/test/ssh_compat_SUITE.erl b/lib/ssh/test/ssh_compat_SUITE.erl
index 56127e98e2..0b1357ca05 100644
--- a/lib/ssh/test/ssh_compat_SUITE.erl
+++ b/lib/ssh/test/ssh_compat_SUITE.erl
@@ -80,7 +80,7 @@ groups() ->
ssh_image_versions() ->
try
%% Find all useful containers in such a way that undefined command, too low
- %% priviliges, no containers and containers found give meaningful result:
+ %% privileges, no containers and containers found give meaningful result:
L0 = ["REPOSITORY"++_|_] = string:tokens(os:cmd("docker images"), "\r\n"),
[["REPOSITORY","TAG"|_]|L1] = [string:tokens(E, " ") || E<-L0],
[list_to_atom(V) || [?DOCKER_PFX,V|_] <- L1]
@@ -151,7 +151,7 @@ init_per_group(G, Config0) ->
ct:comment("~s",[NewCmnt])
end,
AuthMethods =
- %% This should be obtained by quering the peer, but that
+ %% This should be obtained by querying the peer, but that
%% is a bit hard. It is possible with ssh_protocol_SUITE
%% techniques, but it can wait.
case Vssh of
@@ -409,7 +409,7 @@ send_recv_big_with_renegotiate_otp_is_client(Config) ->
Data = << <<X:32>> || X <- lists:seq(1, HalfSizeBytes div 4)>>,
%% Send the data. Must spawn a process to avoid deadlock. The client will block
- %% until all is sent through the send window. But the server will stop receiveing
+ %% until all is sent through the send window. But the server will stop receiving
%% when the servers send-window towards the client is full.
%% Since the client can't receive before the server has received all but 655k from the client
%% ssh_connection:send/4 is blocking...
@@ -875,7 +875,7 @@ new_dir(Config) ->
%%--------------------------------------------------------------------
%%
-%% Find the intersection of algoritms for otp ssh and the docker ssh.
+%% Find the intersection of algorithms for otp ssh and the docker ssh.
%% Returns {ok, ServerHello, Server, ClientHello, Client} where Server are the algorithms common
%% with the docker server and analogous for Client.
%%
@@ -1097,7 +1097,7 @@ receive_hello(S, Ack) ->
receive_kexinit(_S, <<PacketLen:32, PaddingLen:8, PayloadAndPadding/binary>>)
- when PacketLen < 5000, % heuristic max len to stop huge attempts if packet decodeing get out of sync
+ when PacketLen < 5000, % heuristic max len to stop huge attempts if packet decoding get out of sync
size(PayloadAndPadding) >= (PacketLen-1) % Need more bytes?
->
ct:log("Has all ~p packet bytes",[PacketLen]),
diff --git a/lib/ssh/test/ssh_connection_SUITE.erl b/lib/ssh/test/ssh_connection_SUITE.erl
index 1e79f0a622..78a0f65edb 100644
--- a/lib/ssh/test/ssh_connection_SUITE.erl
+++ b/lib/ssh/test/ssh_connection_SUITE.erl
@@ -209,7 +209,7 @@ end_per_suite(_Config) ->
init_per_group(openssh, Config) ->
case ssh_test_lib:gen_tcp_connect(?SSH_DEFAULT_PORT, []) of
{error,econnrefused} ->
- {skip,"No openssh deamon (econnrefused)"};
+ {skip,"No openssh daemon (econnrefused)"};
{ok, Socket} ->
gen_tcp:close(Socket),
ssh_test_lib:openssh_sanity_check(Config)
@@ -679,7 +679,7 @@ do_interrupted_send(Config, SendSize, EchoSize) ->
ct:log("~p:~p got expected data",[?MODULE,?LINE]),
ok;
Other ->
- ct:log("~p:~p unexpect: ~p", [?MODULE,?LINE,Other]),
+ ct:log("~p:~p unexpected: ~p", [?MODULE,?LINE,Other]),
{fail,"unexpected result in listener"}
catch
Class:Exception ->
@@ -1236,7 +1236,7 @@ start_shell_sock_daemon_exec_multi(Config) ->
receive
{ssh_cm, ConnectionRef, {data, _ChannelId, 0, <<"echo testing\n">>}} ->
Parent ! {answer_received,self()},
- ct:log("~p:~p: recevied result on connection ~p", [?MODULE,?LINE,ConnectionRef])
+ ct:log("~p:~p: received result on connection ~p", [?MODULE,?LINE,ConnectionRef])
after 5000 ->
ct:fail("Exec Timeout")
end
diff --git a/lib/ssh/test/ssh_options_SUITE.erl b/lib/ssh/test/ssh_options_SUITE.erl
index 7543e9f53c..594378cda3 100644
--- a/lib/ssh/test/ssh_options_SUITE.erl
+++ b/lib/ssh/test/ssh_options_SUITE.erl
@@ -1412,7 +1412,7 @@ max_sessions(Config, ParallelLogin, Connect0) when is_function(Connect0,2) ->
ct:log("Connections up: ~p",[Connections]),
[_|_] = Connections,
- %% N w try one more than alowed:
+ %% N w try one more than allowed:
ct:pal("Info Report expected here (if not disabled) ...",[]),
try Connect(Host,Port)
of
@@ -1442,7 +1442,7 @@ try_to_connect(Connect, Host, Port, Pid, Tref, N) ->
of
_ConnectionRef1 ->
timer:cancel(Tref),
- ct:log("Step 3 ok: could set up one more connection after killing one. Thats good.",[]),
+ ct:log("Step 3 ok: could set up one more connection after killing one. That's good.",[]),
ssh:stop_daemon(Pid),
receive % flush.
timeout_no_connection -> ok
@@ -1769,7 +1769,7 @@ config_file_modify_algorithms_order(Config) ->
ConnOptions = proplists:get_value(options, ConnInfo),
ConnPrefAlgs = proplists:get_value(preferred_algorithms, ConnOptions),
- %% And now, are all levels appied in right order:
+ %% And now, are all levels applied in right order:
[K3,K2] = proplists:get_value(kex, ConnPrefAlgs),
peer:stop(Peer)
@@ -1789,7 +1789,7 @@ expected_ssh_vsn(Str) ->
"\r\n" -> true;
_ -> false
catch
- _:_ -> true %% ssh not started so we dont't know
+ _:_ -> true %% ssh not started so we don't know
end.
diff --git a/lib/ssh/test/ssh_protocol_SUITE.erl b/lib/ssh/test/ssh_protocol_SUITE.erl
index 7e94bf60c7..dbe862eab6 100644
--- a/lib/ssh/test/ssh_protocol_SUITE.erl
+++ b/lib/ssh/test/ssh_protocol_SUITE.erl
@@ -717,7 +717,7 @@ client_info_line(Config) ->
%%% The server does not send the extension because
%%% the client does not tell the server to send it
no_ext_info_s1(Config) ->
- %% Start the dameon
+ %% Start the daemon
Server = {Pid,_,_} = ssh_test_lib:daemon([{send_ext_info,true},
{system_dir, system_dir(Config)}]),
{ok,AfterKexState} = connect_and_kex([{server,Server}|Config]),
@@ -732,7 +732,7 @@ no_ext_info_s1(Config) ->
%%% The server does not send the extension because
%%% the server is not configured to send it
no_ext_info_s2(Config) ->
- %% Start the dameon
+ %% Start the daemon
Server = {Pid,_,_} = ssh_test_lib:daemon([{send_ext_info,false},
{system_dir, system_dir(Config)}]),
{ok,AfterKexState} = connect_and_kex([{extra_options,[{recv_ext_info,true}]},
@@ -748,7 +748,7 @@ no_ext_info_s2(Config) ->
%%%--------------------------------------------------------------------
%%% The server sends the extension
ext_info_s(Config) ->
- %% Start the dameon
+ %% Start the daemon
Server = {Pid,_,_} = ssh_test_lib:daemon([{send_ext_info,true},
{system_dir, system_dir(Config)}]),
{ok,AfterKexState} = connect_and_kex([{extra_options,[{recv_ext_info,true}]},
@@ -984,7 +984,7 @@ chk_pref_algs(Config,
ExpectedKex,
ExpectedCiphers,
ServerPrefOpts) ->
- %% Start the dameon
+ %% Start the daemon
case ssh_test_lib:daemon(
[{send_ext_info,false},
{recv_ext_info,false},
@@ -1103,7 +1103,7 @@ std_connect({Host,Port}, Config, Opts) ->
std_connect(Host, Port, Config, Opts) ->
{User,Pwd} = server_user_password(Config),
ssh:connect(Host, Port,
- %% Prefere User's Opts to the default opts
+ %% Prefer User's Opts to the default opts
[O || O = {Tag,_} <- [{user,User},{password,Pwd},
{silently_accept_hosts, true},
{save_accepted_host, false},
diff --git a/lib/ssh/test/ssh_pubkey_SUITE.erl b/lib/ssh/test/ssh_pubkey_SUITE.erl
index 81c32e0197..d03d4e61c5 100644
--- a/lib/ssh/test/ssh_pubkey_SUITE.erl
+++ b/lib/ssh/test/ssh_pubkey_SUITE.erl
@@ -836,8 +836,8 @@ chk_known_hosts(Config) ->
%%%----------------------------------------------------------------
-try_connect({skip,Reson}) ->
- {skip,Reson};
+try_connect({skip,Reason}) ->
+ {skip,Reason};
try_connect(Config) ->
SystemDir = proplists:get_value(system_dir, Config),
UserDir = proplists:get_value(user_dir, Config),
diff --git a/lib/ssh/test/ssh_pubkey_SUITE_data/public_key/ssh_rsa_long_comment_pub b/lib/ssh/test/ssh_pubkey_SUITE_data/public_key/ssh_rsa_long_comment_pub
index 7b42ced93e..bca5a375ca 100644
--- a/lib/ssh/test/ssh_pubkey_SUITE_data/public_key/ssh_rsa_long_comment_pub
+++ b/lib/ssh/test/ssh_pubkey_SUITE_data/public_key/ssh_rsa_long_comment_pub
@@ -1,7 +1,7 @@
---- BEGIN SSH2 PUBLIC KEY ----
Comment: This is an example of a very very very very looooooooooooo\
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooong\
-commment
+comment
x-command: /home/me/bin/lock-in-guest.sh
AAAAB3NzaC1yc2EAAAABIwAAAIEA1on8gxCGJJWSRT4uOrR13mUaUk0hRf4RzxSZ1zRb
YYFw8pfGesIFoEuVth4HKyF8k1y4mRUnYHP1XNMNMJl1JcEArC2asV8sHf6zSPVffozZ
diff --git a/lib/ssh/test/ssh_pubkey_SUITE_data/public_key/ssh_rsa_long_header_pub b/lib/ssh/test/ssh_pubkey_SUITE_data/public_key/ssh_rsa_long_header_pub
index 7b42ced93e..bca5a375ca 100644
--- a/lib/ssh/test/ssh_pubkey_SUITE_data/public_key/ssh_rsa_long_header_pub
+++ b/lib/ssh/test/ssh_pubkey_SUITE_data/public_key/ssh_rsa_long_header_pub
@@ -1,7 +1,7 @@
---- BEGIN SSH2 PUBLIC KEY ----
Comment: This is an example of a very very very very looooooooooooo\
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooong\
-commment
+comment
x-command: /home/me/bin/lock-in-guest.sh
AAAAB3NzaC1yc2EAAAABIwAAAIEA1on8gxCGJJWSRT4uOrR13mUaUk0hRf4RzxSZ1zRb
YYFw8pfGesIFoEuVth4HKyF8k1y4mRUnYHP1XNMNMJl1JcEArC2asV8sHf6zSPVffozZ
diff --git a/lib/ssh/test/ssh_relay.erl b/lib/ssh/test/ssh_relay.erl
index 3bb4cb2071..f7aac11c7c 100644
--- a/lib/ssh/test/ssh_relay.erl
+++ b/lib/ssh/test/ssh_relay.erl
@@ -313,7 +313,7 @@ listen(Parent, LSock) ->
do_listen(Parent, LSock).
do_listen(Parent, LSock) ->
- %% So annoying there is no select-like sematic for this
+ %% So annoying there is no select-like semantics for this
case gen_tcp:accept(LSock, ?ACCEPT_TMO) of
{ok, Sock} ->
Parent ! {accept, Sock},
diff --git a/lib/ssh/test/ssh_sftpd_SUITE.erl b/lib/ssh/test/ssh_sftpd_SUITE.erl
index 70a0049730..1d897c28b3 100644
--- a/lib/ssh/test/ssh_sftpd_SUITE.erl
+++ b/lib/ssh/test/ssh_sftpd_SUITE.erl
@@ -405,7 +405,7 @@ rename_file(Config) when is_list(Config) ->
NewReqId1 = NewReqId + 1,
file:copy(FileName, NewFileName),
- %% No owerwrite
+ %% No overwrite
{ok, <<?SSH_FXP_STATUS, ?UINT32(NewReqId1),
?UINT32(?SSH_FX_FILE_ALREADY_EXISTS), _/binary>>, _} =
rename(FileName, NewFileName, Cm, Channel, NewReqId1, 6,
@@ -685,7 +685,7 @@ access_outside_root(Config) when is_list(Config) ->
BadFilePath = filename:join([BaseDir, bad]),
ok = file:write_file(BadFilePath, <<>>),
{Cm, Channel} = proplists:get_value(sftp, Config),
- %% Try to access a file parallell to the RootDir:
+ %% Try to access a file parallel to the RootDir:
try_access("/../bad", Cm, Channel, 0),
%% Try to access the same file via the CWD which is /b relative to the RootDir:
try_access("../../bad", Cm, Channel, 1).
@@ -717,7 +717,7 @@ try_access(Path, Cm, Channel, ReqId) ->
end
end;
_ ->
- ct:fail("Completly unexpected return: ~p", [Return])
+ ct:fail("Completely unexpected return: ~p", [Return])
end.
%%--------------------------------------------------------------------
diff --git a/lib/ssh/test/ssh_test_lib.erl b/lib/ssh/test/ssh_test_lib.erl
index acabb66a48..08c9638213 100644
--- a/lib/ssh/test/ssh_test_lib.erl
+++ b/lib/ssh/test/ssh_test_lib.erl
@@ -627,14 +627,14 @@ default_algorithms(sshc, DaemonOptions) ->
{hostport,Srvr,{_Host,Port}} ->
spawn(fun()-> os:cmd(lists:concat(["ssh -o \"StrictHostKeyChecking no\" -p ",Port," localhost"])) end)
after ?TIMEOUT ->
- ct:fail("No server respons (timeout) 1")
+ ct:fail("No server response (timeout) 1")
end,
receive
{result,Srvr,L} ->
L
after ?TIMEOUT ->
- ct:fail("No server respons (timeout) 2")
+ ct:fail("No server response (timeout) 2")
end.
run_fake_ssh({ok,InitialState}) ->
@@ -940,7 +940,7 @@ create_random_dir(Config) ->
Name;
{error,eexist} ->
%% The Name already denotes an existing file system object, try again.
- %% The likelyhood of always generating an existing file name is low
+ %% The likelihood of always generating an existing file name is low
create_random_dir(Config)
end.
diff --git a/lib/ssh/test/ssh_to_openssh_SUITE.erl b/lib/ssh/test/ssh_to_openssh_SUITE.erl
index a36b4036a5..c61907ec28 100644
--- a/lib/ssh/test/ssh_to_openssh_SUITE.erl
+++ b/lib/ssh/test/ssh_to_openssh_SUITE.erl
@@ -91,7 +91,7 @@ init_per_suite(Config) ->
?CHECK_CRYPTO(
case gen_tcp:connect("localhost", ?SSH_DEFAULT_PORT, []) of
{error,econnrefused} ->
- {skip,"No openssh deamon (econnrefused)"};
+ {skip,"No openssh daemon (econnrefused)"};
_ ->
ssh_test_lib:openssh_sanity_check(
[{ptty_supported, ssh_test_lib:ptty_supported()}
diff --git a/lib/ssh/test/ssh_trpt_test_lib.erl b/lib/ssh/test/ssh_trpt_test_lib.erl
index eea392bd35..d21324a9d3 100644
--- a/lib/ssh/test/ssh_trpt_test_lib.erl
+++ b/lib/ssh/test/ssh_trpt_test_lib.erl
@@ -47,7 +47,7 @@
prints = [],
return_value,
- %% Packet retrival and decryption
+ %% Packet retrieval and decryption
decrypted_data_buffer = <<>>,
encrypted_data_buffer = <<>>,
aead_data = <<>>,
@@ -343,7 +343,7 @@ send(S0=#s{alg_neg={undefined,PeerMsg}}, Msg=#ssh_msg_kexinit{}) ->
S1#s{alg = Cx#ssh.algorithms}
catch
Class:Exc ->
- save_prints({"Algoritm negotiation failed at line ~p:~p~n~p:~s~nPeer: ~s~n Own: ~s~n",
+ save_prints({"Algorithm negotiation failed at line ~p:~p~n~p:~s~nPeer: ~s~n Own: ~s~n",
[?MODULE,?LINE,Class,format_msg(Exc),format_msg(PeerMsg),format_msg(Msg)]},
S1)
end;
@@ -361,8 +361,8 @@ send(S0, ssh_msg_kexdh_init) when ?role(S0) == client ->
try ssh_transport:handle_kexinit_msg(PeerMsg, OwnMsg, S0#s.ssh)
catch
Class:Exc ->
- fail("Algoritm negotiation failed!",
- {"Algoritm negotiation failed at line ~p:~p~n~p:~s~nPeer: ~s~n Own: ~s",
+ fail("Algorithm negotiation failed!",
+ {"Algorithm negotiation failed at line ~p:~p~n~p:~s~nPeer: ~s~n Own: ~s",
[?MODULE,?LINE,Class,format_msg(Exc),format_msg(PeerMsg),format_msg(OwnMsg)]},
S0)
end,
@@ -429,7 +429,7 @@ recv(S0 = #s{}) ->
%% Must see hello before binary messages
try_find_crlf(<<>>, S1);
true ->
- %% Has seen hello, therefore no more crlf-messages are alowed.
+ %% Has seen hello, therefore no more crlf-messages are allowed.
S = receive_binary_msg(S1),
case PeerMsg = S#s.return_value of
#ssh_msg_kexinit{} ->
@@ -451,7 +451,7 @@ recv(S0 = #s{}) ->
alg = C#ssh.algorithms}
catch
Class:Exc ->
- save_prints({"Algoritm negotiation failed at line ~p:~p~n~p:~s~nPeer: ~s~n Own: ~s~n",
+ save_prints({"Algorithm negotiation failed at line ~p:~p~n~p:~s~nPeer: ~s~n Own: ~s~n",
[?MODULE,?LINE,Class,format_msg(Exc),format_msg(PeerMsg),format_msg(OwnMsg)]},
S#s{alg_neg = {OwnMsg, PeerMsg}})
end
@@ -650,7 +650,7 @@ ok({error,E}) -> erlang:error(E).
%%%================================================================
%%%
-%%% Formating of records
+%%% Formatting of records
%%%
format_msg(M) -> format_msg(M, 0).
diff --git a/lib/ssh/test/ssh_upgrade_SUITE.erl b/lib/ssh/test/ssh_upgrade_SUITE.erl
index 7c7c93e04b..731e9d1b20 100644
--- a/lib/ssh/test/ssh_upgrade_SUITE.erl
+++ b/lib/ssh/test/ssh_upgrade_SUITE.erl
@@ -98,7 +98,7 @@ minor_upgrade(Config) when is_list(Config) ->
%%%
%%%----------------------------------------------------------------
-%%% Initialyze system before upgrade test starts.
+%%% Initialize system before upgrade test starts.
%%% Called by ct_release_test:upgrade/4
upgrade_init(CTData, State) ->
{ok, AppUp={_, _, Up, _Down}} = ct_release_test:get_appup(CTData, ssh),
diff --git a/lib/ssh/src/ssh_connection_handler.erl b/lib/ssh/src/ssh_connection_handler.erl
index 2bee158f26..e84dbf7bc1 100644
--- a/lib/ssh/src/ssh_connection_handler.erl
+++ b/lib/ssh/src/ssh_connection_handler.erl
@@ -425,7 +425,7 @@ init([Role, Socket, Opts]) when Role==client ; Role==server ->
end.
%%%----------------------------------------------------------------
-%%% Connection start and initalization helpers
+%%% Connection start and initialization helpers
init_connection_record(Role, Socket, Opts) ->
{WinSz, PktSz} = init_inet_buffers_window(Socket),
@@ -625,7 +625,7 @@ handle_event(internal, {version_exchange,Version}, {hello,Role}, D0) ->
{NumVsn, StrVsn} = ssh_transport:handle_hello_version(Version),
case handle_version(NumVsn, StrVsn, D0#data.ssh_params) of
{ok, Ssh1} ->
- %% Since the hello part is finnished correctly, we set the
+ %% Since the hello part is finished correctly, we set the
%% socket to the packet handling mode (including recbuf size):
inet:setopts(D0#data.socket, [{packet,0},
{mode,binary},
@@ -651,7 +651,7 @@ handle_event(state_timeout, no_hello_received, {hello,_Role}=StateName, D0 = #da
Time = ?GET_OPT(hello_timeout, Ssh0#ssh.opts),
{Shutdown, D} =
?send_disconnect(?SSH_DISCONNECT_PROTOCOL_ERROR,
- lists:concat(["No HELLO recieved within ",ssh_lib:format_time_ms(Time)]),
+ lists:concat(["No HELLO received within ",ssh_lib:format_time_ms(Time)]),
StateName, D0),
{stop, Shutdown, D};
@@ -939,7 +939,7 @@ handle_event({call,From}, {request, ChannelPid, ChannelId, Type, Data, Timeout},
{error,Error} ->
{keep_state, D0, {reply,From,{error,Error}}};
D ->
%% Note reply to channel will happen later when reply is recived from peer on the socket
start_channel_request_timer(ChannelId, From, Timeout),
{keep_state, D, cond_set_idle_timer(D)}
end;
@@ -950,7 +950,7 @@ handle_event({call,From}, {request, ChannelId, Type, Data, Timeout}, StateName,
{error,Error} ->
{keep_state, D0, {reply,From,{error,Error}}};
D ->
%% Note reply to channel will happen later when reply is recived from peer on the socket
start_channel_request_timer(ChannelId, From, Timeout),
{keep_state, D, cond_set_idle_timer(D)}
end;
@@ -1242,7 +1242,7 @@ handle_event(info, {'EXIT', _Sup, Reason}, StateName, _D) ->
{stop, {shutdown, Reason}};
Reason == normal ->
- %% An exit normal should not cause a server to crash. This has happend...
+ %% An exit normal should not cause a server to crash. This has happened...
keep_state_and_data;
true ->
@@ -1583,7 +1583,7 @@ handle_ssh_msg_ext_info(#ssh_msg_ext_info{data=Data}, D0) ->
ext_info({"server-sig-algs",SigAlgsStr},
D0 = #data{ssh_params=#ssh{role=client,
userauth_pubkeys=ClientSigAlgs}=Ssh0}) ->
- %% ClientSigAlgs are the pub_key algortithms that:
+ %% ClientSigAlgs are the pub_key algorithms that:
%% 1) is usable, that is, the user has such a public key and
%% 2) is either the default list or set by the caller
%% with the client option 'pref_public_key_algs'
@@ -939,7 +939,7 @@ handle_event({call,From}, {request, ChannelPid, ChannelId, Type, Data, Timeout},
{keep_state, D0, {reply,From,{error,Error}}};
D ->
- %% Note reply to channel will happen later when reply is recived from peer on the socket
+ %% Note reply to channel will happen later when reply is received from peer on the socket
start_channel_request_timer(ChannelId, From, Timeout),
{keep_state, D, cond_set_idle_timer(D)}
@@ -950,7 +950,7 @@ handle_event({call,From}, {request, ChannelId, Type, Data, Timeout}, StateName,
{keep_state, D0, {reply,From,{error,Error}}};
D ->
- %% Note reply to channel will happen later when reply is recived from peer on the socket
+ %% Note reply to channel will happen later when reply is received from peer on the socket
start_channel_request_timer(ChannelId, From, Timeout),
{keep_state, D, cond_set_idle_timer(D)}